SCCD: Constructs an SCCD for a specified number of runs (n=2m). The...

View source: R/SCCD.R

SCCDR Documentation

Constructs an SCCD for a specified number of runs (n=2m). The construction method is selected automatically according to the number of runs.

Description

Constructs an SCCD for a specified number of runs (n=2m). The construction method is selected automatically according to the number of runs.

Usage

SCCD(n)

Arguments

n

A positive even integer specifying the number of runs.

Details

Method I is used when n is divisible by 8. Method II is used when n is divisible by 4 but not by 8. Method III is used when n is even but not divisible by 4.

Value

A numeric SCCD matrix containing m continuous and m-1 categorical factors.

Examples

SCCD(16)

SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.

Related to SCCD in SCCDdesign...