SCCD_method1: Construct Saturated screening designs for continous and...

View source: R/SCCD.R

SCCD_method1R Documentation

Construct Saturated screening designs for continous and categorical factor (SCCD) Using Method I Constructs an SCCD when the number of runs (n=2m) is divisible by 8, using a conference matrix and a Hadamard matrix. The number of continuous factor is m and the number of categorical factors is m-1)

Description

Construct Saturated screening designs for continous and categorical factor (SCCD) Using Method I Constructs an SCCD when the number of runs (n=2m) is divisible by 8, using a conference matrix and a Hadamard matrix. The number of continuous factor is m and the number of categorical factors is m-1)

Usage

SCCD_method1(n)

Arguments

n

A positive integer specifying the number of runs.

Value

A numeric SCCD matrix.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.