SCCD_method2: Construct SCCD Using Method II Constructs an SCCD when the...

View source: R/SCCD.R

SCCD_method2R Documentation

Construct SCCD Using Method II Constructs an SCCD when the number of runs (n=2m) is divisible by 4 but not divisible by 8, using a conference matrix and a D-optimal two-level design. The number of continuous factor is m and number of categorical factors is m-1

Description

Construct SCCD Using Method II Constructs an SCCD when the number of runs (n=2m) is divisible by 4 but not divisible by 8, using a conference matrix and a D-optimal two-level design. The number of continuous factor is m and number of categorical factors is m-1

Usage

SCCD_method2(n)

Arguments

n

A positive integer specifying the number of runs.

Value

A numeric SCCD matrix.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.