SCCD_method3: Construct SCCD Using Method III Constructs an SCCD when the...

View source: R/SCCD.R

SCCD_method3R Documentation

Construct SCCD Using Method III Constructs an SCCD when the number of runs (n=2m) is even but not divisible by 4, using a pseudo-conference matrix and a D-optimal two-level design. The number of continuous factor is m and the number of categorical factors is m-1)

Description

Construct SCCD Using Method III Constructs an SCCD when the number of runs (n=2m) is even but not divisible by 4, using a pseudo-conference matrix and a D-optimal two-level design. The number of continuous factor is m and the number of categorical factors is m-1)

Usage

SCCD_method3(n, starts = 1000, max.iter = 100)

Arguments

n

A positive integer specifying the number of runs.

starts

Number of random starting matrices used in the pseudo-conference matrix search. Default is 1000.

max.iter

Maximum number of iterations for each starting matrix. Default is 100.

Value

A numeric SCCD matrix.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.