even_even_design: Constructs an orthogonal design for two types of even-level...

View source: R/even_even_design.R

even_even_designR Documentation

Constructs an orthogonal design for two types of even-level factors using a Hadamard matrix. The first column of the Hadamard matrix is removed, and scaled copies of the resulting matrix are combined to obtain the required factor levels.

Description

Constructs an orthogonal design for two types of even-level factors using a Hadamard matrix. The first column of the Hadamard matrix is removed, and scaled copies of the resulting matrix are combined to obtain the required factor levels.

Usage

even_even_design(a, b, m)

Arguments

a

Number of levels for the first factor. Must be even.

b

Number of levels for the second factor. Must be even.

m

Order of the Hadamard matrix.Must be a multiple of 4. The constructed design contains m - 1 factors of each of the two factor types.

Value

A matrix containing the constructed design. The first m - 1 columns correspond to the first type factor, and the remaining m - 1 columns correspond to the second type factor.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.