hadamardMatrix: Constructs a Hadamard matrix of order 'n' using...

View source: R/hadamardMatrix.R

hadamardMatrixR Documentation

Constructs a Hadamard matrix of order n using pracma::hadamard().

Description

Constructs a Hadamard matrix of order n using pracma::hadamard().

Usage

hadamardMatrix(n)

Arguments

n

A positive integer specifying the order of the matrix.

Details

A Hadamard matrix contains only +1 and -1, and its rows are mutually orthogonal. The supported orders are of the forms 2^e, 12(2^e), and 20(2^e).

Value

A Hadamard matrix of order n.

Examples

hadamardMatrix(4)
hadamardMatrix(8)
hadamardMatrix(12)

SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.