View source: R/primeFunctions.R
| is_prime_power | R Documentation |
Check for a Prime Power. Checks whether q is a prime or a power of a prime number.
is_prime_power(q)
q |
A positive integer to be checked. |
TRUE if q is a prime or prime power and FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.