jacobsthalPrime: Jacobsthal Matrix for a Prime Constructs a Jacobsthal matrix...

View source: R/paleyConstruction.R

jacobsthalPrimeR Documentation

Jacobsthal Matrix for a Prime Constructs a Jacobsthal matrix when q is prime using the quadratic character modulo q.

Description

Jacobsthal Matrix for a Prime Constructs a Jacobsthal matrix when q is prime using the quadratic character modulo q.

Usage

jacobsthalPrime(q)

Arguments

q

A prime number specifying the order of the Jacobsthal matrix.

Value

A numeric Jacobsthal matrix of order q.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.