jacobsthalPrimePower: Jacobsthal Matrix for a Prime Power Constructs a Jacobsthal...

View source: R/paleyConstruction.R

jacobsthalPrimePowerR Documentation

Jacobsthal Matrix for a Prime Power Constructs a Jacobsthal matrix over the finite field GF(p^m) when q = p^m is an odd prime power.

Description

Jacobsthal Matrix for a Prime Power Constructs a Jacobsthal matrix over the finite field GF(p^m) when q = p^m is an odd prime power.

Usage

jacobsthalPrimePower(q)

Arguments

q

An odd prime power specifying the order of the Jacobsthal matrix.

Value

A numeric Jacobsthal matrix of order q.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.