odd_odd_design: Constructs an orthogonal design for two types of odd-level...

View source: R/odd_odd_design.R

odd_odd_designR Documentation

Constructs an orthogonal design for two types of odd-level factors using conference matrices.

Description

Constructs an orthogonal design for two types of odd-level factors using conference matrices.

Usage

odd_odd_design(a, b, m)

Arguments

a

Number of levels for the first odd-level factor.

b

Number of levels for the second odd-level factor.

m

Order of the conference matrix. Must be a multiple of 4.The design contains m factors of the first odd-level type and m factors of the second odd-level type.

Value

A matrix containing the constructed design. The first m columns correspond to the first odd-level factor and the remaining m columns correspond to the second odd-level factor. Both sets of columns are constructed using a conference matrix.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.