View source: R/paleyConstruction.R
| paleyPrime | R Documentation |
Paley Conference Matrix for a Prime Constructs a Paley conference matrix of order n when q = n - 1 is an odd prime.
paleyPrime(n)
n |
A positive integer specifying the order of the conference matrix. |
A numeric conference matrix of order n.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.