paleyPrimePower: Paley Conference Matrix for a Prime Power Constructs a Paley...

View source: R/paleyConstruction.R

paleyPrimePowerR Documentation

Paley Conference Matrix for a Prime Power Constructs a Paley conference matrix of order n when q = n - 1 is an odd prime power.

Description

Paley Conference Matrix for a Prime Power Constructs a Paley conference matrix of order n when q = n - 1 is an odd prime power.

Usage

paleyPrimePower(n)

Arguments

n

A positive integer specifying the order of the conference matrix.

Value

A numeric conference matrix of order n.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.