| polyMultiply | R Documentation |
Polynomial Multiplication over GF(p Multiplies two polynomials with coefficients in GF(p).
polyMultiply(a, b, p)
a |
A vector containing the coefficients of the first polynomial. |
b |
A vector containing the coefficients of the second polynomial. |
p |
A prime number. |
A vector containing the coefficients of the product modulo p.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.