| polyReduce | R Documentation |
Polynomial Reduction over GF(p) Reduces a polynomial modulo a specified irreducible polynomial over GF(p).
polyReduce(poly, modulus, p)
poly |
A vector containing polynomial coefficients. |
modulus |
A vector containing the coefficients of the irreducible polynomial. |
p |
A prime number. |
The reduced polynomial as a coefficient vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.