primePowerInfo: Identify a Prime Power Determines whether q can be expressed...

View source: R/primeFunctions.R

primePowerInfoR Documentation

Identify a Prime Power Determines whether q can be expressed as p^m, where p is a prime number and m is a positive integer.

Description

Identify a Prime Power Determines whether q can be expressed as p^m, where p is a prime number and m is a positive integer.

Usage

primePowerInfo(q)

Arguments

q

A positive integer to be checked.

Value

A list containing p and m if q is a prime or prime power; otherwise NULL.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.