quadraticCharacterGF: Quadratic Character in a Finite Field Computes the quadratic...

View source: R/finiteField.R

quadraticCharacterGFR Documentation

Quadratic Character in a Finite Field Computes the quadratic character of an element of GF(p^m). It returns 0 for the zero element, 1 for a nonzero quadratic residue, and -1 otherwise.

Description

Quadratic Character in a Finite Field Computes the quadratic character of an element of GF(p^m). It returns 0 for the zero element, 1 for a nonzero quadratic residue, and -1 otherwise.

Usage

quadraticCharacterGF(x, QR)

Arguments

x

A finite-field element.

QR

A matrix containing the nonzero quadratic residues of the finite field.

Value

The quadratic character: 0, 1, or -1.


SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.