View source: R/paleyConstruction.R
| quadraticCharacterPrime | R Documentation |
Quadratic Character Modulo a Prime Computes the quadratic character of an integer modulo a prime. It returns 0 for zero, 1 for a quadratic residue, and -1 otherwise.
quadraticCharacterPrime(x, q, QR)
x |
An integer. |
q |
A prime number. |
QR |
A vector containing the nonzero quadratic residues modulo q. |
The quadratic character: 0, 1, or -1.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.