| quadraticResiduesGF | R Documentation |
Quadratic Residues in a Finite Field Finds the nonzero quadratic residues in GF(p^m).
quadraticResiduesGF(p, m)
p |
A prime number. |
m |
A positive integer specifying the field extension degree. |
A matrix containing the nonzero quadratic residues of GF(p^m).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.