View source: R/paleyConstruction.R
| quadraticResiduesPrime | R Documentation |
Quadratic Residues Modulo a Prime Computes the nonzero quadratic residues modulo a prime number.
quadraticResiduesPrime(q)
q |
A prime number. |
A vector containing the nonzero quadratic residues modulo q.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.