simulation: Performs a simulation study to evaluate the ability of a...

View source: R/simulation.R

simulationR Documentation

Performs a simulation study to evaluate the ability of a design to identify active main effects using best-subsets regression and the AICc criterion.

Description

Performs a simulation study to evaluate the ability of a design to identify active main effects using best-subsets regression and the AICc criterion.

Usage

simulation(X, SNR, n.active, nrep = 1000)

Arguments

X

A design matrix containing the mixed-level factors.

SNR

A numeric value specifying the signal-to-noise ratio.

n.active

An integer specifying the number of active factors.

nrep

An integer specifying the number of simulation replications. Default is 1000.

Value

A data frame containing the SNR, number of active factors, power, and Type I error rate.

Examples

## Not run: 
X <- matrix(rnorm(20 * 5), nrow = 20, ncol = 5)
simulation(X, SNR = 1, n.active = 2, nrep = 100)

## End(Not run)

SCCDdesign documentation built on Sept. 21, 2026, 5:08 p.m.