| SCCD | R Documentation |
Constructs an SCCD for a specified number of runs (n=2m). The construction method is selected automatically according to the number of runs.
SCCD(n)
n |
A positive even integer specifying the number of runs. |
Method I is used when n is divisible by 8. Method II is used when n is divisible by 4 but not by 8. Method III is used when n is even but not divisible by 4.
A numeric SCCD matrix containing m continuous and m-1 categorical factors.
SCCD(16)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.