| SCCD_method1 | R Documentation |
Construct Saturated screening designs for continous and categorical factor (SCCD) Using Method I Constructs an SCCD when the number of runs (n=2m) is divisible by 8, using a conference matrix and a Hadamard matrix. The number of continuous factor is m and the number of categorical factors is m-1)
SCCD_method1(n)
n |
A positive integer specifying the number of runs. |
A numeric SCCD matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.