View source: R/conferenceMatrix.R
| conferenceMatrix | R Documentation |
q = n - 1.Constructs a conference matrix of a specified order using a direct
construction for order 2 and Paley-based constructions for supported
odd prime or prime-power values of q = n - 1.
conferenceMatrix(n)
n |
A single finite integer specifying the order of the conference matrix. The value must be at least 2. |
For n = 2, the conference matrix is constructed directly.
For larger orders, the function sets q = n - 1 and determines
whether q is a supported odd prime or odd prime power.
Depending on the value of q modulo 4, the corresponding
Paley construction is used.
An error is returned when the supplied order does not satisfy the
requirements of the implemented construction.
A numeric n \times n conference matrix.
conferenceMatrix(6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.