View source: R/paleyConstruction.R
| jacobsthalPrime | R Documentation |
Jacobsthal Matrix for a Prime Constructs a Jacobsthal matrix when q is prime using the quadratic character modulo q.
jacobsthalPrime(q)
q |
A prime number specifying the order of the Jacobsthal matrix. |
A numeric Jacobsthal matrix of order q.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.