View source: R/paleyConstruction.R
| jacobsthalPrimePower | R Documentation |
Jacobsthal Matrix for a Prime Power Constructs a Jacobsthal matrix over the finite field GF(p^m) when q = p^m is an odd prime power.
jacobsthalPrimePower(q)
q |
An odd prime power specifying the order of the Jacobsthal matrix. |
A numeric Jacobsthal matrix of order q.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.