View source: R/even_odd_design.R
| odd_even_design | R Documentation |
Constructs an orthogonal design for an odd-level factor and an even-level factor using a conference matrix and a Hadamard matrix, respectively.
odd_even_design(a, b, m)
a |
Number of levels for the odd-level factor. |
b |
Number of levels for the even-level factor. |
m |
Order of the conference and Hadamard matrices. Must be a
multiple of 4.The design contains |
A matrix containing the constructed design. The first m
columns correspond to the odd-level factors and are constructed
using a conference matrix, while the remaining m - 1 columns
correspond to the even-level factors and are constructed using
a Hadamard matrix with its first column removed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.