View source: R/primeFunctions.R
| primePowerInfo | R Documentation |
Identify a Prime Power Determines whether q can be expressed as p^m, where p is a prime number and m is a positive integer.
primePowerInfo(q)
q |
A positive integer to be checked. |
A list containing p and m if q is a prime or prime power; otherwise NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.