View source: R/pseudoConference.R
| pseudoConference | R Documentation |
n
using a determinant-based search procedure.Constructs a pseudo-conference matrix of order n
using a determinant-based search procedure.
pseudoConference(n, starts = 1000, max.iter = 100)
n |
A positive integer specifying the order of the matrix. |
starts |
Number of random starting matrices used in the search. Default is 1000. |
max.iter |
Maximum number of iterations for each starting matrix. Default is 100. |
The matrix has zero diagonal elements and off-diagonal elements equal to -1 or +1. The search selects a matrix by maximizing the determinant criterion.
A list containing the pseudo-conference matrix and the corresponding log-determinant value.
result <- pseudoConference(6, starts = 10, max.iter = 10)
result$Matrix
result$LogDet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.