| quadraticCharacterGF | R Documentation |
Quadratic Character in a Finite Field Computes the quadratic character of an element of GF(p^m). It returns 0 for the zero element, 1 for a nonzero quadratic residue, and -1 otherwise.
quadraticCharacterGF(x, QR)
x |
A finite-field element. |
QR |
A matrix containing the nonzero quadratic residues of the finite field. |
The quadratic character: 0, 1, or -1.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.